@@ -18,7 +18,7 @@ class HeaderAuthentication(BaseAuthentication):
                 request.user = AnonymousUser()
                 return (request.user, None)
 
-            bcmr_auth_token = request.META.get(settings.AUTH_HEADER)
+            bcmr_auth_token = request.META.get('HTTP_BCMR_AUTH')
             if not bcmr_auth_token:
                 if request.method == 'POST':
                     request.user = AnonymousUser()
